//	 KHBO Dept. IW&T
//	 Project microprocessoren en draadloze communicatie
//	 Het ontwerpen van een SDR-radio (Software Defined Radio).
//	 Sturen van een PLL via I2C
//	 Configuratie van de PIC18F4620 microcontroller
//	 XTAL = 8 MHz

#include <p18f4620.h> 
#include "delays.h"


// 4620 config

	#pragma config    OSC = HS
	#pragma config    FCMEN = OFF
	#pragma config    BOREN = ON
	#pragma config    BORV = 1
	#pragma config    WDT = OFF
	#pragma config    WDTPS = 1
	#pragma config    MCLRE = ON
	#pragma config    LPT1OSC =OFF
    #pragma config    PBADEN =OFF // important!
    #pragma config    CCP2MX = PORTBE // CCP2 mux
	#pragma config    STVREN = ON 
	#pragma config    LVP = OFF
	#pragma config    XINST = OFF
	#pragma config    DEBUG = OFF
	#pragma config    CP0 = ON 
	#pragma config    CPB = ON 
	#pragma config    WRT1= ON 
	#pragma config    WRTB = ON 
	#pragma config    WRTC = ON 
	#pragma config    EBTRB = ON


  #define SCL TRISCbits.TRISC3 // SCL line
  #define SDA TRISCbits.TRISC4 // SDA line 

// methoden
void init(); 
void SendStart();
void SendStop();
void SendByte(unsigned char  data);
void ACKSTAT();
void I2CFAIL();
void SSPFlag();

void Strans(unsigned char W);

void main(void){

init();// setup

while(1){ // keep sending data
SendStart(); // send S
SendByte(0x22); // control IN  (input mode)
//ACKSTAT(); // sent?
//SendByte(0x42); // send address (Address Byte)
//ACKSTAT();
//SendByte(0x62); // data
//ACKSTAT();
SendStop();// send P (stop)

// new
//char a ='B';
//Strans ( a); // serial transition


}
}

void init(){
ADCON1=0x07;//Configure A/D
TRISAbits.TRISA0=0; // output
LATAbits.LATA0=1; // hoog zetten van de pint

//TRISCbits.TRISC5=0;
//LATCbits.LATC5=1;
SDA=1; // als uitgang
SCL=1;// uitgang
// MSSP registers 
SSPCON1=0b00101000; // IC master mode , SSPEN enable
SSPSTAT=0b10000000; // Slew Rate control (SMP) 100kHz
// baud rate 100.000kHz
SSPADD = 19; 

// Serial communication
TRISCbits.TRISC6=0;//TX
TRISCbits.TRISC7=1; //RX
TXSTA=0b00100000;// enable transmit 
RCSTA=0b10010000;//enable receive + serial port.
SPBRG=12; // 9600 bps
//RCSTAbits.SPEN=1;//serial port.

}
// The SSPIF flag is checked to ensure the byte has been sent.
void SendStart(){
SSPCON2bits.SEN=1;
SSPFlag();
}

void SendStop(){
SSPCON2bits.PEN=1; // P activeren
SSPFlag();
}

void SendByte(unsigned char data){
SSPBUF= data;
SSPFlag();
}

void I2CFAIL(){
SSPCON2bits.PEN=1;
LATAbits.LATA0=1;
}

void ACKSTAT(){
if ( SSPCON2bits.ACKSTAT==1){ // check ackstat
I2CFAIL(); // STOP
}
}
void SSPFlag() {
while(PIR1bits.SSPIF==0); // wait until sent
PIR1bits.SSPIF=0;
}

void Strans(unsigned char W){
while(PIR1bits.TXIF==0); // wait until the last bit is gone
TXREG=W;

}